@@ -4,8 +4,12 @@ package Mail::Builder;
 use strict;
 use warnings;
 
-use base qw(Class::Accessor);
+use vars qw($VERSION);
+$VERSION = version->new("1.12");
 
+
+use base qw(Class::Accessor);
+use version;
 use Carp;
 
 use Encode qw(encode decode); 
@@ -19,11 +23,9 @@ use Mail::Builder::Attachment::File;
 use Mail::Builder::Attachment::Data;
 use Mail::Builder::Image;
 
-__PACKAGE__->mk_accessors(qw(plaintext htmltext subject organization priority language));
+__PACKAGE__->mk_accessors(qw(plaintext htmltext subject organization priority language mailer autotext));
 __PACKAGE__->mk_ro_accessors(qw(messageid));
 
-use vars qw($VERSION);
-$VERSION = '1.11';
 
 =encoding utf8
 
@@ -64,7 +66,8 @@ The module will create the correct MIME bodies, headers and containers
 you use attachments, HTML text and inline images.
 
 Furthermore it will encode non-ascii header data and autogenerate plaintext
-messages from html content.
+messages (if you don't provide it yourself or disable the
+L<autotext> option) from html content.
 
 Addresses, attachments and inline images are handled as objects by helper
 classes:
@@ -87,8 +90,8 @@ html e-mail body. (E<lt>img src="cid:imageid" /E<gt>)
 
 =item * L<Mail::Builder::List>
 
-Helper class for handling list of varoius items (recipients lists, attachments
-list, images list)
+Helper class for handling list of varoius items (recipient lists, attachment
+lists, image lists)
 
 =back
 
@@ -122,7 +125,9 @@ sub new {
 		language    => undef,
 		attachment	=> Mail::Builder::List->new('Mail::Builder::Attachment'),
 		image		=> Mail::Builder::List->new('Mail::Builder::Image'),
+		mailer      => "Mail::Builder $VERSION with MIME::Tools",
 		messageid   => undef,
+		autotext    => 1,
 	},$class;
 	bless $obj,$class;
 	return $obj;
@@ -192,7 +197,7 @@ sub build_message {
         'Subject'       => encode('MIME-Header',$obj->{'subject'}),
         'Message-ID'    => $obj->{'messageid'},
         'X-Priority'    => $obj->{'priority'},
-        'X-Mailer'      => "Mail::Builder $VERSION with MIME::Tools",
+        'X-Mailer'      => encode('MIME-Header', $obj->{'mailer'}),
     );
     
     # Set reply address
@@ -223,10 +228,10 @@ sub build_message {
     $email_header{'Organization'} = encode('MIME-Header', $obj->{'organization'})
         if ($obj->{'organization'});
     
-    # Build e-mail entity
+    # Build e-mail entity ...
     my $mime_entity;
     
-    # With attachments
+    # ... with attachments
     if ($obj->{'attachment'}->length()) {
         $mime_entity = build MIME::Entity(
             %email_header,
@@ -238,7 +243,7 @@ sub build_message {
             $mime_entity->add_part($_->serialize());
         }
         $mime_entity->add_part($obj->_build_text(Top => 0));
-    # Without attachments
+    # ... without attachments
     } else {
         $mime_entity = $obj->_build_text(%email_header);
     }
@@ -371,13 +376,21 @@ e-mail subject accessor. Must be specified.
 
 HTML mail body accessor.
 
+=head3 mailer
+
+Mailer name.
+
 =head3 plaintext
 
 Plaintext mail body accessor. This text will be autogenerated from htmltext
-if not provided by the user. Simple formating (e.g. <strong>, <em>) will
-be converted to pseudo formating.
+if not provided by the user or the C<autotext> option is turned off. 
+Simple formating (e.g. <strong>, <em>) will be converted to pseudo formating.
 
-The following html tags will be transformed:
+If you want to disable the autogeneration of plaintext parts set the 
+L<autotext> accessor to a false value. However be aware that most spam 
+enginges mark e-mail messages without an plaintext part as spam.
+
+The following html tags will be transformed to simple markup:
 
 =over
 
@@ -437,10 +450,10 @@ a L<Mail::Builder::List> the list will be replaced.
 
 If you pass a Mail::Builder::Attachment object or a scalar path (with an
 optional name an mime type) the current list will be reset and the new 
-attachment will be added. 
+attachment will be added.
 
 The L<Mail::Builder::List> package provides some basic methods for 
-manipulating the list of recipients.
+manipulating the list of attachments.
 
 If you want to append an additional attachment to the list use
 
@@ -470,7 +483,7 @@ If you pass a Mail::Builder::Image object or a scalar path (with an
 optional id) the current list will be reset and the new image will be added. 
 
 The L<Mail::Builder::List> package provides some basic methods for 
-manipulating the list of recipients.
+manipulating the list of inline images.
 
 If you want to append an additional attachment to the list use
 
@@ -479,8 +492,8 @@ If you want to append an additional attachment to the list use
  $obj->image->add(Mail::Builder::Image)
 
 You can embed the image into the html mail body code by referencing the ID. If 
-you don't provide an ID the lowercase filename without the extension will be 
-used as the ID.
+you don't provide an ID the lowercase filename without the file extension will
+be used as the ID.
 
  <img src="cid:logo"/>
 
@@ -677,7 +690,8 @@ sub _build_text
     
     # Build plaintext message from HTML
 	if (defined $obj->{'htmltext'}
-		&& ! defined($obj->{'plaintext'})) {
+		&& ! defined($obj->{'plaintext'})
+		&& $obj->{autotext}) {
 		# Parse HTML tree. Load HTML::TreeBuilder lazily
 		require HTML::TreeBuilder;
 		
@@ -784,7 +798,7 @@ recipients lists.
      $mb->to->add($recipient); # Add current recipient
      
      # Alternatively you could use $mb->to($recipient); which has the
-     # same effect as the two previous commands. Same goes for 'cc' and 'bcc'
+     # same effect as the two previous commands. Same applies to 'cc' and 'bcc'
      
      $mb->plaintext(undef);
      # Reset plaintext, otherwise it will not be autogenerated from htmltext
@@ -797,12 +811,14 @@ recipients lists.
      # Send $mail ... 
  }
  
-=head1 CAVEATS 
+=head1 IMPORTANT CHANGES 
  
 From 1.10 on Mail::Builder only supports utf-8 charsets for mails. Supporting
 multiple encodings turned out to be error prone and not necessary since all
 modern mail clients support utf-8.
 
+=head1 CAVEATS 
+
 Watch out when sending Mail::Builder generated mails with 
 L<Email::Send::SMTP>: The 'Return-Path' headers are ignored by the MTA 
 since L<Email::Send::SMTP> uses the 'From' header for SMTP handshake. Postfix
@@ -851,6 +867,18 @@ LICENSE file included with this module.
 
 The L<Mime::Entity> module in the L<Mime::Tools> distribution.
 
+Furthermore these modules are bing used for various tasks:
+
+=over 
+
+=item * L<Email::Valid> for validating e-mail addresses
+=item * L<HTML::TreeBuilder> for parsing html and generating plaintext
+=item * L<MIME::Types> for guessing attachment mime types
+=item * L<Email::MessageID> for generating unique message IDs
+=item * L<Encode> for encoding issues
+
+=back
+
 =cut
 
 "Thou shalt not send SPAM with this module";
\ No newline at end of file
